summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDaniel Black <daniel@mariadb.org>2022-12-12 16:23:30 +1100
committerAndrew Hutchings <andrew@linuxjedi.co.uk>2022-12-14 20:52:06 +0000
commit952af4a1794ea640213c9c3b3931c84349493a9b (patch)
treef24c7b2b14a6a07f4d16e3f9527fdf49a4cd4e3c
parent687657c270c691cad64b6b55c429af1d63d5cfb2 (diff)
downloadmariadb-git-952af4a1794ea640213c9c3b3931c84349493a9b.tar.gz
Deb: MariaDB names as default for deb scripts
Also include the ftp.mariadb.org script rather than old name.
-rwxr-xr-xdebian/additions/debian-start12
-rwxr-xr-xdebian/additions/debian-start.inc.sh28
-rw-r--r--mysql-test/README2
3 files changed, 21 insertions, 21 deletions
diff --git a/debian/additions/debian-start b/debian/additions/debian-start
index 986fa80fd57..2a8b61ddaff 100755
--- a/debian/additions/debian-start
+++ b/debian/additions/debian-start
@@ -17,12 +17,12 @@ if [ -f /etc/default/mariadb ]; then
. /etc/default/mariadb
fi
-MYSQL="/usr/bin/mysql --defaults-file=/etc/mysql/debian.cnf"
-MYADMIN="/usr/bin/mysqladmin --defaults-file=/etc/mysql/debian.cnf"
-# Don't run full mysql_upgrade on every server restart, use --version-check to do it only once
-MYUPGRADE="/usr/bin/mysql_upgrade --defaults-extra-file=/etc/mysql/debian.cnf --version-check --silent"
-MYCHECK="/usr/bin/mysqlcheck --defaults-file=/etc/mysql/debian.cnf"
-MYCHECK_SUBJECT="WARNING: mysqlcheck has found corrupt tables"
+MARIADB="/usr/bin/mariadb --defaults-file=/etc/mysql/debian.cnf"
+MYADMIN="/usr/bin/mariadb-admin --defaults-file=/etc/mysql/debian.cnf"
+# Don't run full mariadb-upgrade on every server restart, use --version-check to do it only once
+MYUPGRADE="/usr/bin/mariadb-upgrade --defaults-extra-file=/etc/mysql/debian.cnf --version-check --silent"
+MYCHECK="/usr/bin/mariadb-check --defaults-file=/etc/mysql/debian.cnf"
+MYCHECK_SUBJECT="WARNING: mariadb-check has found corrupt tables"
MYCHECK_PARAMS="--all-databases --fast --silent"
MYCHECK_RCPT="${MYCHECK_RCPT:-root}"
diff --git a/mysql-test/README b/mysql-test/README
index 6c7f004a54d..426e66c893b 100644
--- a/mysql-test/README
+++ b/mysql-test/README
@@ -93,7 +93,7 @@ https://mariadb.org/jira/.
If the test case is really big or if it contains 'not public' data,
then put your .test file and .result file(s) into a tar.gz archive,
add a README that explains the problem, ftp the archive to
-ftp://ftp.askmonty.org/private and submit a report to
+ftp://ftp.mariadb.org/private and submit a report to
https://mariadb.org/jira about it.
The latest information about mysql-test-run can be found at:
diff --git a/debian/additions/debian-start.inc.sh b/debian/additions/debian-start.inc.sh
index 005aa290866..8a59f877aca 100755
--- a/debian/additions/debian-start.inc.sh
+++ b/debian/additions/debian-start.inc.sh
@@ -11,7 +11,7 @@ function check_for_crashed_tables() {
set -u
# But do it in the background to not stall the boot process.
- logger -p daemon.info -i -t$0 "Triggering myisam-recover for all MyISAM tables and aria-recover for all Aria tables"
+ logger -p daemon.info -i -t"$0" "Triggering myisam-recover for all MyISAM tables and aria-recover for all Aria tables"
# Checking for $? is unreliable so the size of the output is checked.
# Some table handlers like HEAP do not support CHECK TABLE.
@@ -20,15 +20,15 @@ function check_for_crashed_tables() {
# We have to use xargs in this case, because a for loop barfs on the
# spaces in the thing to be looped over.
# If a crashed table is encountered, the "mysql" command will return with a status different from 0
set +e
- LC_ALL=C $MYSQL --skip-column-names --batch -e '
+ LC_ALL=C $MARIADB --skip-column-names --batch -e '
select concat('\''select count(*) into @discard from `'\'',
TABLE_SCHEMA, '\''`.`'\'', TABLE_NAME, '\''`'\'')
from information_schema.TABLES where TABLE_SCHEMA<>'\''INFORMATION_SCHEMA'\'' and TABLE_SCHEMA<>'\''PERFORMANCE_SCHEMA'\'' and ( ENGINE='\''MyISAM'\'' or ENGINE='\''Aria'\'' )' | \
- xargs -i $MYSQL --skip-column-names --silent --batch \
- --force -e "{}" &>$tempfile
+ xargs -i "${MARIADB}" --skip-column-names --silent --batch \
+ --force -e "{}" &>"${tempfile}"
set -e
if [ -s "$tempfile" ]; then
@@ -37,14 +37,14 @@ function check_for_crashed_tables() {
"Improperly closed tables are also reported if clients are accessing\n" \
"the tables *now*. A list of current connections is below.\n";
$MYADMIN processlist status
- ) >> $tempfile
+ ) >> "${tempfile}"
# Check for presence as a dependency on mailx would require an MTA.
if [ -x /usr/bin/mailx ]; then
- mailx -e -s"$MYCHECK_SUBJECT" $MYCHECK_RCPT < $tempfile
+ mailx -e -s"$MYCHECK_SUBJECT" $MYCHECK_RCPT < "$tempfile"
fi
- (echo "$MYCHECK_SUBJECT"; cat $tempfile) | logger -p daemon.warn -i -t$0
+ (echo "$MYCHECK_SUBJECT"; cat "${tempfile}") | logger -p daemon.warn -i -t"$0"
fi
- rm $tempfile
+ rm "${tempfile}"
}
## Check for tables needing an upgrade.
@@ -54,14 +54,14 @@ function upgrade_system_tables_if_necessary() {
set -e
set -u
- logger -p daemon.info -i -t$0 "Upgrading MySQL tables if necessary."
+ logger -p daemon.info -i -t"$0" "Upgrading MySQL tables if necessary."
# Filter all "duplicate column", "duplicate key" and "unknown column"
# errors as the script is designed to be idempotent.
LC_ALL=C $MYUPGRADE \
2>&1 \
| egrep -v '^(1|@had|ERROR (1051|1054|1060|1061|1146|1347|1348))' \
- | logger -p daemon.warn -i -t$0
+ | logger -p daemon.warn -i -t"$0"
}
## Check for the presence of both, root accounts with and without password.
@@ -70,10 +70,10 @@ function check_root_accounts() {
set -e
set -u
- logger -p daemon.info -i -t$0 "Checking for insecure root accounts."
+ logger -p daemon.info -i -t"$0" "Checking for insecure root accounts."
- ret=$( echo "SELECT count(*) FROM mysql.user WHERE user='root' and password='' and plugin in ('', 'mysql_native_password', 'mysql_old_password');" | $MYSQL --skip-column-names )
+ ret=$( echo "SELECT count(*) FROM mysql.user WHERE user='root' and password='' and plugin in ('', 'mysql_native_password', 'mysql_old_password');" | "$MARIADB" --skip-column-names )
if [ "$ret" -ne "0" ]; then
- logger -p daemon.warn -i -t$0 "WARNING: mysql.user contains $ret root accounts without password!"
+ logger -p daemon.warn -i -t"$0" "WARNING: mysql.user contains $ret root accounts without password!"
fi
}
@@ -20,15 +20,15 @@ function check_for_crashed_tables() {
# We have to use xargs in this case, because a for loop barfs on the
# spaces in the thing to be looped over.
- # If a crashed table is encountered, the "mysql" command will return with a status different from 0
+ # If a crashed table is encountered, the "mariadb" command will return with a status different from 0
set +e